==> nextcloud-10.0.2.tar.bz2: nextcloud/apps/files/l10n/sl.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Določen prostor ni veljaven",
    "Unknown error" : "Neznana napaka",
    "Files" : "Datoteke",
    "All files" : "Vse datoteke",
    "Recent" : "Nedavno",
    "File could not be found" : "Datoteke ne najdem",
    "Home" : "Domači naslov",
    "Close" : "Zapri",
    "Favorites" : "Priljubljene",
    "Could not create folder \"{dir}\"" : "Ni mogoče ustvariti mape \"{dir}\"",
    "Upload cancelled." : "Pošiljanje je preklicano.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ni mogoče poslati datoteke {filename}, saj je to ali mapa ali pa je velikost datoteke 0 bajtov.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Na voljo ni dovolj prostora. Velikost poslane datoteke je {size1}, na voljo pa je je {size2}.",
    "Uploading..." : "Poteka pošiljanje ...",
    "..." : "...",
    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "še {hours}:{minutes}:{seconds} ur{plural_s}",
    "{hours}:{minutes}h" : "{hours}:{minutes}h",
    "{minutes}:{seconds} minute{plural_s} left" : "še {minutes}:{seconds} minut{plural_s}",
    "{minutes}:{seconds}m" : "{minutes}:{seconds}min",
    "{seconds} second{plural_s} left" : "še {seconds} sekund{plural_s}",
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "Vsak trenutek ...",
    "Soon..." : "Kmalu",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} od {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "V teku je pošiljanje datoteke. Če zapustite to stran zdaj, bo pošiljanje preklicano.",
    "Actions" : "Dejanja",
    "Download" : "Prejmi",
    "Rename" : "Preimenuj",
    "Delete" : "Izbriši",
    "Disconnect storage" : "Odklopi shrambo",
    "Unshare" : "Prekini souporabo",
    "Details" : "Podrobnosti",
    "Select" : "Izberi",
    "Pending" : "V čakanju ...",
    "Unable to determine date" : "Ni mogoče določiti datuma",
    "This operation is forbidden" : "To dejanje ni dovoljeno!",
    "This directory is unavailable, please check the logs or contact the administrator" : "Mapa ni na voljo. Preverite dnevnik in stopite v stik s skrbnikom sistema.",
    "Could not move \"{file}\", target exists" : "Datoteke \"{file}\" ni mogoče premakniti, ker cilj že obstaja",
    "Could not move \"{file}\"" : "Ni mogoče premakniti \"{file}\"",
    "{newName} already exists" : "{newName} že obstaja",
    "Could not rename \"{fileName}\", it does not exist any more" : "Ni mogoče preimenovati \"{fileName}\", ker datoteka ne obstaja več",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime \"{targetName}\" je že v uporabi v mapi \"{dir}\". Izberite drugo ime ali drugo mapo.",
    "Could not rename \"{fileName}\"" : "Ni mogoče preimenovati \"{fileName}\"",
    "Could not create file \"{file}\"" : "Ni mogoče ustvariti datoteke \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Ni mogoče ustvariti datoteke \"{file}\", ker že obstaja",
    "Could not create folder \"{dir}\" because it already exists" : "Ni mogoče ustvariti mape \"{dir}\", ker že obstaja",
    "Error deleting file \"{fileName}\"." : "Napaka brisanja datoteke \"{fileName}\".",
    "Name" : "Ime",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno",
    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n map"],
    "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datotek"],
    "{dirs} and {files}" : "{dirs} in {files}",
    "_including %n hidden_::_including %n hidden_" : ["Vključujoč %n skrit","Vključujoč %n skrita","Vključujoč %n skritih","Vključujoč %n skritih"],
    "You don’t have permission to upload or create files here" : "Ni ustreznih dovoljenj za pošiljanje ali ustvarjanje datotek na tem mestu.",
    "_Uploading %n file_::_Uploading %n files_" : ["Posodabljanje %n datoteke","Posodabljanje %n datotek","Posodabljanje %n datotek","Posodabljanje %n datotek"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neveljavno ime datoteke.",
    "File name cannot be empty." : "Ime datoteke ne sme biti prazno polje.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Shramba uporabnika {owner} je polna, zato datotek ni več mogoče posodabljati in usklajevati!",
    "Your storage is full, files can not be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Shramba uporabnika {owner} je polna ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)" : "Prostor za shranjevanje je skoraj do konca zaseden ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["se sklada s filtrom '{filter}'","se skladata s filtrom '{filter}'","se skladajo s filtrom '{filter}'","se skladajo s filtrom '{filter}'"],
    "View in folder" : "Prikaži v mapi",
    "Path" : "Pot",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
    "Favorited" : "Označeno kot priljubljeno",
    "Favorite" : "Priljubljene",
    "Folder" : "Mapa",
    "New folder" : "Nova mapa",
    "Upload" : "Pošlji",
    "An error occurred while trying to update the tags" : "Prišlo je do napake med posodabljanjem oznak",
    "A new file or folder has been <strong>created</strong>" : "Nova datoteka ali mapa je <strong>ustvarjena</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Omeji obvestila o ustvarjanju in spreminjanju <strong>najpogosteje uporabljenih </strong> datotek <em>(omogoči pretok)</em>",
    "Upload (max. %s)" : "Pošiljanje (omejitev %s)",
    "File handling" : "Upravljanje z datotekami",
    "Maximum upload size" : "Največja velikost za pošiljanja",
    "max. possible: " : "največ mogoče:",
    "Save" : "Shrani",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Uveljavljanje sprememb prek PHP-FPM lahko traja tudi 5  minut.",
    "Missing permissions to edit from here." : "Ni ustreznih dovoljenj za urejanje na tej ravni.",
    "Settings" : "Nastavitve",
    "Show hidden files" : "Pokaži skrite datoteke",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Uporabite naslov <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\"> za dostop do datotek prek sistema WebDAV</a>.",
    "No files in here" : "V mapi ni datotek",
    "Upload some content or sync with your devices!" : "Uvozite vsebino ali pa omogočite usklajevanje z napravami!",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Select all" : "izberi vse",
    "Upload too large" : "Prekoračenje omejitve velikosti",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke, ki jih želite poslati, presegajo največjo dovoljeno velikost na strežniku.",
    "No favorites" : "Ni priljubljenih predmetov",
    "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo zbrane na tem mestu.",
    "Text file" : "Besedilna datoteka",
    "New text file.txt" : "Nova datoteka.txt",
    "Storage not available" : "Na voljo ni dovolj prostora",
    "Unable to set upload directory." : "Mapo, v katero boste prenašali dokumente, ni mogoče določiti",
    "Invalid Token" : "Neveljaven žeton",
    "No file was uploaded. Unknown error" : "Ni poslane datoteke. Neznana napaka.",
    "There is no error, the file uploaded with success" : "Datoteka je uspešno naložena.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Poslana datoteka presega dovoljeno velikost, ki je določena z možnostjo upload_max_filesize v datoteki php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Poslana datoteka presega velikost, ki jo določa parameter največje dovoljene velikosti v obrazcu HTML.",
    "The uploaded file was only partially uploaded" : "Poslan je le del datoteke.",
    "No file was uploaded" : "Ni poslane datoteke",
    "Missing a temporary folder" : "Manjka začasna mapa",
    "Failed to write to disk" : "Pisanje na disk je spodletelo",
    "Not enough storage available" : "Na voljo ni dovolj prostora",
    "The target folder has been moved or deleted." : "Ciljna mapa je premaknjena ali izbrisana.",
    "Upload failed. Could not find uploaded file" : "Pošiljanje je spodletelo. Ni mogoče najti poslane datoteke.",
    "Upload failed. Could not get file info." : "Pošiljanje je spodletelo. Ni mogoče pridobiti podrobnosti datoteke.",
    "Invalid directory." : "Neveljavna mapa.",
    "Total file size {size1} exceeds upload limit {size2}" : "Skupna velikost {size1} presega omejitev velikosti {size2}",
    "Error uploading file \"{fileName}\": {message}" : "Napaka pošiljanja datoteke \"{fileName}\": {message}",
    "Could not get result from server." : "Ni mogoče pridobiti podatkov s strežnika.",
    "No entries in this folder match '{filter}'" : "Ni zadetkov, ki bi bili skladni z nizom '{filter}'",
    "Local link" : "Krajevna povezava",
    "{newname} already exists" : "{newname} že obstaja",
    "A file or folder has been <strong>changed</strong>" : "Datoteka ali mapa je <strong>spremenjena</strong>.",
    "A file or folder has been <strong>deleted</strong>" : "Datoteka ali mapa je <strong>izbrisana</strong>.",
    "A file or folder has been <strong>restored</strong>" : "Datoteka ali mapa je <strong>obnovljena</strong>.",
    "You created %1$s" : "Ustvarili ste %1$s",
    "%2$s created %1$s" : "%2$s je ustvaril %1$s",
    "%1$s was created in a public folder" : "Datoteka %1$s je ustvarjena v javni mapi.",
    "You changed %1$s" : "Spremenili ste %1$s",
    "%2$s changed %1$s" : "%2$s je spremenil %1$s",
    "You deleted %1$s" : "Izbrisali ste %1$s",
    "%2$s deleted %1$s" : "%2$s je izbrisal %1$s",
    "You restored %1$s" : "Obnovljen je predmet %1$s",
    "%2$s restored %1$s" : "Uporabnik %2$s je obnovil predmet %1$s.",
    "Changed by %2$s" : "Zadnja sprememba: %2$s",
    "Deleted by %2$s" : "Izbrisano: %2$s",
    "Restored by %2$s" : "Obnovljeno: %2$s",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Uporabi ta naslov za <a href=\"%s\" target=\"_blank\">dostop do tvojih datotek preko WebDAV</a>",
    "Cancel upload" : "Prekini nalaganje"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-12.0.5.tar.bz2: nextcloud/apps/files/l10n/sl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
    "Storage invalid" : "Določen prostor ni veljaven",
    "Unknown error" : "Neznana napaka",
    "All files" : "Vse datoteke",
    "Recent" : "Nedavno",
    "File could not be found" : "Datoteke ne najdem",
    "Home" : "Domači naslov",
    "Close" : "Zapri",
    "Favorites" : "Priljubljene",
    "Could not create folder \"{dir}\"" : "Ni mogoče ustvariti mape \"{dir}\"",
    "Upload cancelled." : "Pošiljanje je preklicano.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ni mogoče poslati datoteke {filename}, saj je to ali mapa ali pa je velikost datoteke 0 bajtov.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Na voljo ni dovolj prostora. Velikost poslane datoteke je {size1}, na voljo pa je je {size2}.",
    "Target folder \"{dir}\" does not exist any more" : "Ciljna mapa \"{dir}\" ne obstaja več",
    "Not enough free space" : "Ni dovolj prostora",
    "…" : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} od {totalSize} ({bitrate})",
    "Actions" : "Dejanja",
    "Download" : "Prejmi",
    "Rename" : "Preimenuj",
    "Move or copy" : "Premakni ali kopiraj",
    "Target folder" : "Ciljna mapa",
    "Delete" : "Izbriši",
    "Disconnect storage" : "Odklopi shrambo",
    "Unshare" : "Prekini souporabo",
    "Could not load info for file \"{file}\"" : "Ni bilo mogoče naložiti podatke za datoteko \"{file}\"",
    "Files" : "Datoteke",
    "Details" : "Podrobnosti",
    "Select" : "Izberi",
    "Pending" : "V čakanju ...",
    "Unable to determine date" : "Ni mogoče določiti datuma",
    "This operation is forbidden" : "To dejanje ni dovoljeno!",
    "This directory is unavailable, please check the logs or contact the administrator" : "Mapa ni na voljo. Preverite dnevnik in stopite v stik s skrbnikom sistema.",
    "Could not move \"{file}\", target exists" : "Datoteke \"{file}\" ni mogoče premakniti, ker cilj že obstaja",
    "Could not move \"{file}\"" : "Ni mogoče premakniti \"{file}\"",
    "{newName} already exists" : "{newName} že obstaja",
    "Could not rename \"{fileName}\", it does not exist any more" : "Ni mogoče preimenovati \"{fileName}\", ker datoteka ne obstaja več",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime \"{targetName}\" je že v uporabi v mapi \"{dir}\". Izberite drugo ime ali drugo mapo.",
    "Could not rename \"{fileName}\"" : "Ni mogoče preimenovati \"{fileName}\"",
    "Could not create file \"{file}\"" : "Ni mogoče ustvariti datoteke \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Ni mogoče ustvariti datoteke \"{file}\", ker že obstaja",
    "Could not create folder \"{dir}\" because it already exists" : "Ni mogoče ustvariti mape \"{dir}\", ker že obstaja",
    "Error deleting file \"{fileName}\"." : "Napaka brisanja datoteke \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ni rezultatov iskanja v drugih mapah {tag}{filter}{endtag}",
    "Name" : "Ime",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno",
    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n mape"],
    "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datoteke"],
    "{dirs} and {files}" : "{dirs} in {files}",
    "_including %n hidden_::_including %n hidden_" : ["Vključujoč %n skrit","Vključujoč %n skrita","Vključujoč %n skritih","Vključujoč %n skritih"],
    "You don’t have permission to upload or create files here" : "Ni ustreznih dovoljenj za pošiljanje ali ustvarjanje datotek na tem mestu.",
    "_Uploading %n file_::_Uploading %n files_" : ["Posodabljanje %n datoteke","Posodabljanje %n datotek","Posodabljanje %n datotek","Posodabljanje %n datotek"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neveljavno ime datoteke.",
    "File name cannot be empty." : "Ime datoteke ne sme biti prazno polje.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" ni dovoljena vrsta datoteke",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Shramba uporabnika {owner} je polna, zato datotek ni več mogoče posodabljati in usklajevati!",
    "Your storage is full, files can not be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Shramba uporabnika {owner} je polna ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)" : "Prostor za shranjevanje je skoraj do konca zaseden ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["se sklada s filtrom '{filter}'","se skladata s filtrom '{filter}'","se skladajo s filtrom '{filter}'","se skladajo s filtrom '{filter}'"],
    "View in folder" : "Prikaži v mapi",
    "Copied!" : "Kopirano!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiraj direktno povezavo (deluje sa mo za uporabnike, ki imajo dostop do datoteke ali mape)",
    "Path" : "Pot",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
    "Favorited" : "Označeno kot priljubljeno",
    "Favorite" : "Priljubljene",
    "New folder" : "Nova mapa",
    "Upload file" : "Naloži datoteko",
    "An error occurred while trying to update the tags" : "Prišlo je do napake med posodabljanjem oznak",
    "Added to favorites" : "Dodano med priljubljene",
    "Removed from favorites" : "Odstranjeno iz priljubljenih",
    "You added {file} to your favorites" : "Dodali ste {file} med priljubljene",
    "You removed {file} from your favorites" : "Odstranili ste {file} od priljubljenih",
    "File changes" : "Sprememba datoteke",
    "Created by {user}" : "Ustvarjeno od {user}",
    "Changed by {user}" : "Spremenjeno od {user}",
    "Deleted by {user}" : "Izbrisano od {user}",
    "Restored by {user}" : "Obnovljeno od {user}",
    "Renamed by {user}" : "Preimenovano od {user}",
    "Moved by {user}" : "Premaknjeno od {user}",
    "\"remote user\"" : "\"oddaljeni uporabnik\"",
    "You created {file}" : "Ustvaril(a) si {file}",
    "{user} created {file}" : "{user} ustvaril(a) {file}",
    "{file} was created in a public folder" : "{file} ustvarjena je bila v javni mapi",
    "You changed {file}" : "Spremenil(a) si {file}",
    "{user} changed {file}" : "{user} spremenil/a {file}",
    "You deleted {file}" : "Izbrisal(a) si {file}",
    "{user} deleted {file}" : "{user} izbrisal(a) {file}",
    "You restored {file}" : "Obnovil(a) si {file}",
    "{user} restored {file}" : "{user} obnovil(a) {file}",
    "You renamed {oldfile} to {newfile}" : "Preimenoval(a) si {oldfile} v {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} preimenoval(a) {oldfile} v {newfile}",
    "You moved {oldfile} to {newfile}" : "Premaknil(a) si {oldfile} v {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} premaknil(a) {oldfile} v {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Datoteka je bila dodana ali umaknjena iz tvojih <strong>priljubljenih</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Datoteka ali mapa je bila <strong>spremenjena</strong> ali <strong>preimenovana</strong>",
    "A new file or folder has been <strong>created</strong>" : "Nova datoteka ali mapa je <strong>ustvarjena</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Datoteka ali mapa je bila <strong>pobrisana</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Omeji obvestila o ustvarjanju in spreminjanju <strong>najpogosteje uporabljenih </strong> datotek <em>(omogoči pretok)</em>",
    "A file or folder has been <strong>restored</strong>" : "A file or folder has been <strong>restored</strong>",
    "Unlimited" : "Neomejeno",
    "Upload (max. %s)" : "Pošiljanje (omejitev %s)",
    "File handling" : "Upravljanje z datotekami",
    "Maximum upload size" : "Največja velikost za pošiljanja",
    "max. possible: " : "največ mogoče:",
    "Save" : "Shrani",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Uveljavljanje sprememb prek PHP-FPM lahko traja tudi 5  minut.",
    "Missing permissions to edit from here." : "Ni ustreznih dovoljenj za urejanje na tej ravni.",
    "%s of %s used" : "%s od %s uporabljeno",
    "%s used" : "%s uporabljeno",
    "Settings" : "Nastavitve",
    "Show hidden files" : "Pokaži skrite datoteke",
    "WebDAV" : "WebDAV",
    "Cancel upload" : "Prekini nalaganje",
    "No files in here" : "V mapi ni datotek",
    "Upload some content or sync with your devices!" : "Uvozite vsebino ali pa omogočite usklajevanje z napravami!",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Select all" : "izberi vse",
    "Upload too large" : "Prekoračenje omejitve velikosti",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke, ki jih želite poslati, presegajo največjo dovoljeno velikost na strežniku.",
    "No favorites yet" : "Še ni priljubljena",
    "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo zbrane na tem mestu.",
    "Shared with you" : "V skupni rabi z vami",
    "Shared with others" : "V skupni rabi z ostalimi",
    "Shared by link" : "Deljeno s povezavo",
    "Tags" : "Oznake",
    "Deleted files" : "Izbrisane datoteke",
    "Text file" : "Besedilna datoteka",
    "New text file.txt" : "Nova datoteka.txt",
    "Uploading..." : "Poteka pošiljanje ...",
    "..." : "...",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["{hours}:{minutes}:{seconds} ura še","{hours}:{minutes}:{seconds} uri še","{hours}:{minutes}:{seconds} ure še","{hours}:{minutes}:{seconds} ur še"],
    "{hours}:{minutes}h" : "{hours}:{minutes}h",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["{minutes}:{seconds} minuta še","{minutes}:{seconds} minuti še","{minutes}:{seconds} minute še","{minutes}:{seconds} minut še"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}min",
    "_{seconds} second left_::_{seconds} seconds left_" : ["{seconds} sekund še","{seconds} sekundi še","{seconds} sekunde še","{seconds} sekund še"],
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "Vsak trenutek ...",
    "Soon..." : "Kmalu",
    "File upload is in progress. Leaving the page now will cancel the upload." : "V teku je pošiljanje datoteke. Če zapustite to stran zdaj, bo pošiljanje preklicano.",
    "Move" : "Premakni",
    "Copy local link" : "Kopiraj lokalno povezavo",
    "Folder" : "Mapa",
    "Upload" : "Pošlji",
    "A new file or folder has been <strong>deleted</strong>" : "Nova datoteka ali mapa je bila <strong>pobrisana</strong>",
    "A new file or folder has been <strong>restored</strong>" : "Nova datoteka ali mapa je bila <strong>obnovljena</strong>",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Uporabite naslov <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\"> za dostop do datotek prek sistema WebDAV</a>.",
    "No favorites" : "Ni priljubljenih predmetov"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
